CreateTaskResultResponse class
The JSON-RPC response wrapping a successful CreateTaskResult.
Constructors
- CreateTaskResultResponse({required String id, required CreateTaskResult result})
- Creates a CreateTaskResultResponse.
-
CreateTaskResultResponse.toMCP(Map<
String, Object?> map) -
Builds a CreateTaskResultResponse from a decoded MCP JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- jsonrpc ↔ String
-
getter/setter pair
- result ↔ CreateTaskResult
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
Converts this CreateTaskResultResponse into a JSON-compatible map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited