ElicitRequestFormParams class

The parameters for a request to elicit non-sensitive information from the user via a form in the client.

Inheritance

Constructors

ElicitRequestFormParams({TaskMetadata? task, RequestMetaObject? $meta, required String message, ElicitRequestFormParamsSchema? requestedSchema})
Creates an ElicitRequestFormParams.
ElicitRequestFormParams.toMCP(Map<String, Object?> map)
Builds an ElicitRequestFormParams from a decoded MCP JSON map.
factory

Properties

$meta RequestMetaObject?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
jsonrpc String
getter/setter pairinherited
message String
The message to present to the user describing what information is being requested.
getter/setter pair
node String
getter/setter pair
requestedSchema ElicitRequestFormParamsSchema?
A restricted subset of JSON Schema.
getter/setter pair
result ElicitResult
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task TaskMetadata?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ElicitRequestFormParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited