ElicitRequestURLParams class

The parameters for a request to elicit information from the user via a URL in the client.

Inheritance

Constructors

ElicitRequestURLParams({TaskMetadata? task, RequestMetaObject? $meta, required String message, required String elicitationId, required String url})
Creates an ElicitRequestURLParams.
ElicitRequestURLParams.toMCP(Map<String, Object?> map)
Builds an ElicitRequestURLParams from a decoded MCP JSON map.
factory

Properties

$meta RequestMetaObject?
getter/setter pair
elicitationId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
jsonrpc String
getter/setter pairinherited
message String
The message to present to the user explaining why the interaction is needed.
getter/setter pair
node String
getter/setter pair
result ElicitResult
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task TaskMetadata?
getter/setter pair
url String
The URL that the user should navigate to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this ElicitRequestURLParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited