GetTaskRequest class

A JSON-RPC request for the getTask operation.

Inheritance

Constructors

GetTaskRequest({required String id, required GetTaskRequestParams params})
Creates a GetTaskRequest.
GetTaskRequest.toMCP(Map<String, Object?> map)
Builds a GetTaskRequest from a decoded MCP JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
jsonrpc String
getter/setter pair
method String
getter/setter pair
params GetTaskRequestParams
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this GetTaskRequest into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited