MapMC<K, V> class abstract

A MapModel that also satisfies MCP.

Use as the base class when the model is the underlying map (e.g. InitializeResult, ClientCapabilities).

Implemented types
Implementers

Constructors

MapMC(Map<K, V> data)
Creates a MapMC.

Properties

data Map<K, V>
The underlying map data.
finalinherited
entries Iterable<MapEntry<K, V>>
See Map.entries.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
See Map.isEmpty.
no setterinherited
isNotEmpty bool
See Map.isNotEmpty.
no setterinherited
keys Iterable<K>
See Map.keys.
no setterinherited
length int
See Map.length.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable<V>
See Map.values.
no setterinherited

Methods

addAll(Map<K, V> other) → void
See Map.addAll.
inherited
addEntries(Iterable<MapEntry<K, V>> newEntries) → void
See Map.addEntries.
inherited
cast<RK, RV>() Map<RK, RV>
See Map.cast.
inherited
clear() → void
See Map.clear.
inherited
containsKey(Object? key) bool
See Map.containsKey.
inherited
containsValue(Object? value) bool
See Map.containsValue.
inherited
forEach(void action(K key, V value)) → void
See Map.forEach.
inherited
map<K2, V2>(MapEntry<K2, V2> convert(K key, V value)) Map<K2, V2>
See Map.map.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(K key, V ifAbsent()) → V
See Map.putIfAbsent.
inherited
remove(Object? key) → V?
See Map.remove.
inherited
removeWhere(bool test(K key, V value)) → void
See Map.removeWhere.
inherited
toMap() Map<String, Object?>
Converts this object into a JSON-compatible map.
inherited
toString() String
A string representation of this object.
inherited
update(K key, V update(V value), {V ifAbsent()?}) → V
See Map.update.
inherited
updateAll(V update(K key, V value)) → void
See Map.updateAll.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → V?
Delegates to the underlying map's [] operator.
inherited
operator []=(K key, V value) → void
Delegates to the underlying map's []= operator.
inherited