SetLevelRequestParams class

Parameters for SetLevelRequest.

Inheritance

Constructors

SetLevelRequestParams({RequestMetaObject? $meta, required LoggingLevel level})
Creates a SetLevelRequestParams.
SetLevelRequestParams.toMCP(Map<String, Object?> map)
Builds a SetLevelRequestParams from a decoded MCP JSON map.
factory

Properties

$meta RequestMetaObject?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
level LoggingLevel
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this SetLevelRequestParams into a JSON-compatible map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited